Crate that contains bytecode types and opcode constants.
Legacy bytecode will always contain a jump table.
While EIP-7702 bytecode must contains a Address.
Re-exports
pub use bytecode::Bytecode;pub use bytecode::BytecodeKind;pub use opcode::OpCode;pub use bitvec;
Modules
- bytecode
- Module that contains the bytecode struct with all variants supported by Ethereum mainnet.
- eip7702
- EIP-7702 bytecode. EIP-7702 bytecode constants and error types.
- opcode
- EVM opcode definitions and utilities. It contains opcode information and utilities to work with opcodes.
- utils
- Various utilities for the bytecode
Structs
- Bytecode
Iterator - Iterator over opcodes in a bytecode, skipping immediates.
- Jump
Table - A table of valid
jumpdestinations.
Enums
- Bytecode
Decode Error - Bytecode decode errors